---
documentclass: article
header-includes: |
 \usepackage{graphicx}
 \usepackage[a4paper,margin=3cm]{geometry}
 \usepackage[italian]{babel}
 \usepackage{microtype}
---


\begin{center}
    \includegraphics[width=0.6\textwidth]{thesis/logo-unibg.png}
    
    {
    \Large
    Scuola di Ingegneria \\~\\
    Dipartimento di Ingegneria dell'Informazione, della Gestione e della Produzione \\~\\
    Classe n. L-8 -  Classe delle lauree in Ingegneria dell'Informazione
    }

    \vspace{1.3cm}
    
    {
    \huge
    \textbf{Realizzazione di una libreria Python su cloud per la fusione e l'analisi dei dati dalla scena del crimine}
    }

    \vspace{1.3cm}
    
    {
    \Large
    \textbf{Federico Aguzzi}
        
    \vfill

    Candidato:\\
    \emph{Federico Aguzzi}\\
    Matricola n. 1066519
        
    \vspace{0.6cm}

    Relatore:\\
    \emph{Chiar.mo Prof.\\Angelo Michele Gargantini}
    }
        
\end{center}


\renewcommand{\baselinestretch}{1.5}
